# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brymck/risk/v1/risk_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from brymck.risk.v1 import covariance_pb2 as brymck_dot_risk_dot_v1_dot_covariance__pb2
from brymck.risk.v1 import frequency_pb2 as brymck_dot_risk_dot_v1_dot_frequency__pb2
from brymck.risk.v1 import return_time_series_entry_pb2 as brymck_dot_risk_dot_v1_dot_return__time__series__entry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='brymck/risk/v1/risk_api.proto',
  package='brymck.risk.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.github.brymck.risk.v1B\014RiskApiProtoP\001Z\006riskv1\242\002\003BRX\252\002\016Brymck.Risk.V1\312\002\016Brymck\\Risk\\V1'),
  serialized_pb=_b('\n\x1d\x62rymck/risk/v1/risk_api.proto\x12\x0e\x62rymck.risk.v1\x1a\x1f\x62rymck/risk/v1/covariance.proto\x1a\x1e\x62rymck/risk/v1/frequency.proto\x1a-brymck/risk/v1/return_time_series_entry.proto\"S\n\x0eGetRiskRequest\x12\x13\n\x0bsecurity_id\x18\x01 \x01(\x04\x12,\n\tfrequency\x18\x02 \x01(\x0e\x32\x19.brymck.risk.v1.Frequency\"\x1f\n\x0fGetRiskResponse\x12\x0c\n\x04risk\x18\x01 \x01(\x01\"[\n\x15GetCovariancesRequest\x12\x14\n\x0csecurity_ids\x18\x01 \x03(\x04\x12,\n\tfrequency\x18\x02 \x01(\x0e\x32\x19.brymck.risk.v1.Frequency\"M\n\x16GetCovariancesResponse\x12\x33\n\x0b\x63ovariances\x18\x01 \x03(\x0b\x32\x1e.brymck.risk.v1.CovariancePair\"_\n\x1aGetReturnTimeSeriesRequest\x12\x13\n\x0bsecurity_id\x18\x01 \x01(\x04\x12,\n\tfrequency\x18\x02 \x01(\x0e\x32\x19.brymck.risk.v1.Frequency\"U\n\x1bGetReturnTimeSeriesResponse\x12\x36\n\x07\x65ntries\x18\x01 \x03(\x0b\x32%.brymck.risk.v1.ReturnTimeSeriesEntry2\xa6\x02\n\x07RiskAPI\x12J\n\x07GetRisk\x12\x1e.brymck.risk.v1.GetRiskRequest\x1a\x1f.brymck.risk.v1.GetRiskResponse\x12_\n\x0eGetCovariances\x12%.brymck.risk.v1.GetCovariancesRequest\x1a&.brymck.risk.v1.GetCovariancesResponse\x12n\n\x13GetReturnTimeSeries\x12*.brymck.risk.v1.GetReturnTimeSeriesRequest\x1a+.brymck.risk.v1.GetReturnTimeSeriesResponseB[\n\x19\x63om.github.brymck.risk.v1B\x0cRiskApiProtoP\x01Z\x06riskv1\xa2\x02\x03\x42RX\xaa\x02\x0e\x42rymck.Risk.V1\xca\x02\x0e\x42rymck\\Risk\\V1b\x06proto3')
  ,
  dependencies=[brymck_dot_risk_dot_v1_dot_covariance__pb2.DESCRIPTOR,brymck_dot_risk_dot_v1_dot_frequency__pb2.DESCRIPTOR,brymck_dot_risk_dot_v1_dot_return__time__series__entry__pb2.DESCRIPTOR,])




_GETRISKREQUEST = _descriptor.Descriptor(
  name='GetRiskRequest',
  full_name='brymck.risk.v1.GetRiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_id', full_name='brymck.risk.v1.GetRiskRequest.security_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='brymck.risk.v1.GetRiskRequest.frequency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=244,
)


_GETRISKRESPONSE = _descriptor.Descriptor(
  name='GetRiskResponse',
  full_name='brymck.risk.v1.GetRiskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='risk', full_name='brymck.risk.v1.GetRiskResponse.risk', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=277,
)


_GETCOVARIANCESREQUEST = _descriptor.Descriptor(
  name='GetCovariancesRequest',
  full_name='brymck.risk.v1.GetCovariancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_ids', full_name='brymck.risk.v1.GetCovariancesRequest.security_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='brymck.risk.v1.GetCovariancesRequest.frequency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=370,
)


_GETCOVARIANCESRESPONSE = _descriptor.Descriptor(
  name='GetCovariancesResponse',
  full_name='brymck.risk.v1.GetCovariancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='covariances', full_name='brymck.risk.v1.GetCovariancesResponse.covariances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=449,
)


_GETRETURNTIMESERIESREQUEST = _descriptor.Descriptor(
  name='GetReturnTimeSeriesRequest',
  full_name='brymck.risk.v1.GetReturnTimeSeriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_id', full_name='brymck.risk.v1.GetReturnTimeSeriesRequest.security_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='brymck.risk.v1.GetReturnTimeSeriesRequest.frequency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=546,
)


_GETRETURNTIMESERIESRESPONSE = _descriptor.Descriptor(
  name='GetReturnTimeSeriesResponse',
  full_name='brymck.risk.v1.GetReturnTimeSeriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='brymck.risk.v1.GetReturnTimeSeriesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=633,
)

_GETRISKREQUEST.fields_by_name['frequency'].enum_type = brymck_dot_risk_dot_v1_dot_frequency__pb2._FREQUENCY
_GETCOVARIANCESREQUEST.fields_by_name['frequency'].enum_type = brymck_dot_risk_dot_v1_dot_frequency__pb2._FREQUENCY
_GETCOVARIANCESRESPONSE.fields_by_name['covariances'].message_type = brymck_dot_risk_dot_v1_dot_covariance__pb2._COVARIANCEPAIR
_GETRETURNTIMESERIESREQUEST.fields_by_name['frequency'].enum_type = brymck_dot_risk_dot_v1_dot_frequency__pb2._FREQUENCY
_GETRETURNTIMESERIESRESPONSE.fields_by_name['entries'].message_type = brymck_dot_risk_dot_v1_dot_return__time__series__entry__pb2._RETURNTIMESERIESENTRY
DESCRIPTOR.message_types_by_name['GetRiskRequest'] = _GETRISKREQUEST
DESCRIPTOR.message_types_by_name['GetRiskResponse'] = _GETRISKRESPONSE
DESCRIPTOR.message_types_by_name['GetCovariancesRequest'] = _GETCOVARIANCESREQUEST
DESCRIPTOR.message_types_by_name['GetCovariancesResponse'] = _GETCOVARIANCESRESPONSE
DESCRIPTOR.message_types_by_name['GetReturnTimeSeriesRequest'] = _GETRETURNTIMESERIESREQUEST
DESCRIPTOR.message_types_by_name['GetReturnTimeSeriesResponse'] = _GETRETURNTIMESERIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRiskRequest = _reflection.GeneratedProtocolMessageType('GetRiskRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETRISKREQUEST,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetRiskRequest)
  ))
_sym_db.RegisterMessage(GetRiskRequest)

GetRiskResponse = _reflection.GeneratedProtocolMessageType('GetRiskResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRISKRESPONSE,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetRiskResponse)
  ))
_sym_db.RegisterMessage(GetRiskResponse)

GetCovariancesRequest = _reflection.GeneratedProtocolMessageType('GetCovariancesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCOVARIANCESREQUEST,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetCovariancesRequest)
  ))
_sym_db.RegisterMessage(GetCovariancesRequest)

GetCovariancesResponse = _reflection.GeneratedProtocolMessageType('GetCovariancesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCOVARIANCESRESPONSE,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetCovariancesResponse)
  ))
_sym_db.RegisterMessage(GetCovariancesResponse)

GetReturnTimeSeriesRequest = _reflection.GeneratedProtocolMessageType('GetReturnTimeSeriesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETRETURNTIMESERIESREQUEST,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetReturnTimeSeriesRequest)
  ))
_sym_db.RegisterMessage(GetReturnTimeSeriesRequest)

GetReturnTimeSeriesResponse = _reflection.GeneratedProtocolMessageType('GetReturnTimeSeriesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRETURNTIMESERIESRESPONSE,
  __module__ = 'brymck.risk.v1.risk_api_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.GetReturnTimeSeriesResponse)
  ))
_sym_db.RegisterMessage(GetReturnTimeSeriesResponse)


DESCRIPTOR._options = None

_RISKAPI = _descriptor.ServiceDescriptor(
  name='RiskAPI',
  full_name='brymck.risk.v1.RiskAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=636,
  serialized_end=930,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetRisk',
    full_name='brymck.risk.v1.RiskAPI.GetRisk',
    index=0,
    containing_service=None,
    input_type=_GETRISKREQUEST,
    output_type=_GETRISKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCovariances',
    full_name='brymck.risk.v1.RiskAPI.GetCovariances',
    index=1,
    containing_service=None,
    input_type=_GETCOVARIANCESREQUEST,
    output_type=_GETCOVARIANCESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetReturnTimeSeries',
    full_name='brymck.risk.v1.RiskAPI.GetReturnTimeSeries',
    index=2,
    containing_service=None,
    input_type=_GETRETURNTIMESERIESREQUEST,
    output_type=_GETRETURNTIMESERIESRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RISKAPI)

DESCRIPTOR.services_by_name['RiskAPI'] = _RISKAPI

# @@protoc_insertion_point(module_scope)
