# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brymck/risk/v1/frequency.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='brymck/risk/v1/frequency.proto',
  package='brymck.risk.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.github.brymck.risk.v1B\016FrequencyProtoP\001Z\006riskv1\242\002\003BRX\252\002\016Brymck.Risk.V1\312\002\016Brymck\\Risk\\V1'),
  serialized_pb=_b('\n\x1e\x62rymck/risk/v1/frequency.proto\x12\x0e\x62rymck.risk.v1*N\n\tFrequency\x12\x15\n\x11\x46REQUENCY_INVALID\x10\x00\x12\x13\n\x0f\x46REQUENCY_DAILY\x10\x01\x12\x15\n\x11\x46REQUENCY_MONTHLY\x10\x02\x42]\n\x19\x63om.github.brymck.risk.v1B\x0e\x46requencyProtoP\x01Z\x06riskv1\xa2\x02\x03\x42RX\xaa\x02\x0e\x42rymck.Risk.V1\xca\x02\x0e\x42rymck\\Risk\\V1b\x06proto3')
)

_FREQUENCY = _descriptor.EnumDescriptor(
  name='Frequency',
  full_name='brymck.risk.v1.Frequency',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FREQUENCY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FREQUENCY_DAILY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FREQUENCY_MONTHLY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=50,
  serialized_end=128,
)
_sym_db.RegisterEnumDescriptor(_FREQUENCY)

Frequency = enum_type_wrapper.EnumTypeWrapper(_FREQUENCY)
FREQUENCY_INVALID = 0
FREQUENCY_DAILY = 1
FREQUENCY_MONTHLY = 2


DESCRIPTOR.enum_types_by_name['Frequency'] = _FREQUENCY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
